#rockanalysis
Code for Analyzing ISO-10328 Testing Data Obtained from MTS 

## Use
Analyze Class Holds All Data, takes filename as argument

### Methods
decode(), unpacks dat file into arrays \n
plotforcevtime() \n
plotdisplacementvtime() \n
plotforcevdisplacement()
